Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1147)

Unified Diff: content/browser/loader/mojo_stream_writer.h

Issue 1693563002: PROTOTYPE: PlzNavigate: use a Mojo data pipe to stream navigation data to the renderer. Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Browser sends URLRequest id to the renderer and renderer uses intermediary buffer for data: none he… Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/frame_host/render_frame_host_impl.cc ('k') | content/browser/loader/mojo_stream_writer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/loader/mojo_stream_writer.h
diff --git a/content/browser/loader/stream_writer.h b/content/browser/loader/mojo_stream_writer.h
similarity index 58%
copy from content/browser/loader/stream_writer.h
copy to content/browser/loader/mojo_stream_writer.h
index 0b243db8b68b42c01a383de2a8d8688de392649f..73a041c0ae5b8c26dd320005a4a3b0e8c587c373 100644
--- a/content/browser/loader/stream_writer.h
+++ b/content/browser/loader/mojo_stream_writer.h
@@ -1,13 +1,14 @@
-// Copyright 2014 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_BROWSER_LOADER_STREAM_WRITER_H_
-#define CONTENT_BROWSER_LOADER_STREAM_WRITER_H_
+#ifndef CONTENT_BROWSER_LOADER_MOJO_STREAM_WRITER_H_
+#define CONTENT_BROWSER_LOADER_MOJO_STREAM_WRITER_H_
#include "base/macros.h"
#include "base/memory/ref_counted.h"
-#include "content/browser/streams/stream_write_observer.h"
+#include "mojo/message_pump/handle_watcher.h"
+#include "mojo/public/cpp/system/data_pipe.h"
class GURL;
@@ -18,36 +19,31 @@ class IOBuffer;
namespace content {
class ResourceController;
-class Stream;
-class StreamRegistry;
-// StreamWriter is a helper class for ResourceHandlers which route their output
-// into a Stream. It manages an internal buffer and handles back-pressure from
-// the Stream's reader.
-class StreamWriter : public StreamWriteObserver {
+// MojoStreamWriter is a helper class for ResourceHandlers which route their
+// output into Mojo data pipe.
+class MojoStreamWriter {
public:
- // Creates a new StreamWriter without an initialized Stream or controller. The
- // controller must be set before the writer is used.
- StreamWriter();
- ~StreamWriter() override;
+ // Creates a new non-initialized MojoStreamWriter. Both the data pipe handle
+ // and the controller must be set before the writer is used.
+ MojoStreamWriter();
+ ~MojoStreamWriter();
- Stream* stream() { return stream_.get(); }
+ bool has_stream() { return data_producer_handle_.is_valid(); }
void set_controller(ResourceController* controller) {
controller_ = controller;
}
- // When immediate mode is enabled, the |stream_| is flushed every time new
- // data is made available by calls to OnReadCompleted.
- void set_immediate_mode(bool enabled) { immediate_mode_ = enabled; }
-
+ // TODO(carlosk): update comment.
// Initializes the writer with a new Stream in |registry|. |origin| will be
// used to construct the URL for the Stream. See WebCore::BlobURL and and
// WebCore::SecurityOrigin in Blink to understand how origin check is done on
// resource loading.
- void InitializeStream(StreamRegistry* registry,
- const GURL& origin);
+ void InitializeStream(
+ mojo::ScopedDataPipeConsumerHandle* data_consumer_handle);
+ // TODO(carlosk): update comment.
// Prepares a buffer to read data from the request. This call will be followed
// by either OnReadCompleted (on successful read or EOF) or destruction. The
// buffer may not be recycled until OnReadCompleted is called. If |min_size|
@@ -60,6 +56,7 @@ class StreamWriter : public StreamWriteObserver {
int* buf_size,
int min_size);
+ // TODO(carlosk): update comment.
// A read was completed, forward the data to the Stream. If |*defer| is set to
// true, the implementation must not continue to process the request until
// Resume is called on |controller_|.
@@ -70,19 +67,24 @@ class StreamWriter : public StreamWriteObserver {
// Called when there is no more data to read to the stream.
void Finalize();
+ static const int kReadBufSize = 32768;
+
private:
- // StreamWriteObserver implementation.
- void OnSpaceAvailable(Stream* stream) override;
- void OnClose(Stream* stream) override;
+ // TODO(carlosk): chose a more appropriate name and update comment.
+ void OnSpaceAvailable(MojoResult result);
ResourceController* controller_;
- scoped_refptr<Stream> stream_;
- scoped_refptr<net::IOBuffer> read_buffer_;
- bool immediate_mode_;
- DISALLOW_COPY_AND_ASSIGN(StreamWriter);
+ mojo::ScopedDataPipeProducerHandle data_producer_handle_;
+
+ // TODO(carlosk): Refactor to use a mojo::Watcher.
+ mojo::common::HandleWatcher handle_watcher_;
+ void* buffer_;
+ uint32_t buffer_size_;
+
+ DISALLOW_COPY_AND_ASSIGN(MojoStreamWriter);
};
} // namespace content
-#endif // CONTENT_BROWSER_LOADER_STREAM_WRITER_H_
+#endif // CONTENT_BROWSER_LOADER_MOJO_STREAM_WRITER_H_
« no previous file with comments | « content/browser/frame_host/render_frame_host_impl.cc ('k') | content/browser/loader/mojo_stream_writer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698